@@ -30,7 +30,7 @@ class KPEOPLEWIDGETS_EXPORT PersonDetailsView : public QWidget
 {
     Q_OBJECT
 public:
-    PersonDetailsView(QWidget *parent = nullptr);
+    explicit PersonDetailsView(QWidget *parent = nullptr);
     ~PersonDetailsView() override;
 
 public Q_SLOTS:
@@ -39,7 +39,7 @@ public Q_SLOTS:
     //     void setPersonsModel(PersonsModel *model);
 
 private Q_SLOTS:
-    void reload();
+    KPEOPLEWIDGETS_NO_EXPORT void reload();
 
 private:
     Q_DECLARE_PRIVATE(PersonDetailsView)
